@@ -1,16 +1,15 @@
 package App::TemplateServer::Provider;
 use Moose::Role;
-use MooseX::Types::Path::Class qw(Dir);
 
 has 'docroot' => (
-    is       => 'ro',
-    isa      => Dir,
-    required => 1,
-    coerce   => 1,
+    is         => 'ro',
+    isa        => 'ArrayRef[Defined]',
+    required   => 1,
+    auto_deref => 1,
 );
 
-requires 'list_templates';
 requires 'render_template';
+requires 'list_templates';
 
 1;
 
@@ -18,7 +17,7 @@ __END__
 
 =head1 NAME
 
-App::TemplateServer::Provider - role that a Provider should do
+App::TemplateServer::Provider - role that a Provider should consume
 
 =head1 DESCRIPTION
 
@@ -26,15 +25,6 @@ Template systems are interfaced with App::TemplateServer with this
 role.  The template server will call the methods required by this role
 to provider its functionality.
 
-=head1 ATTRIBUTES
-
-This role provides the following attributes:
-
-=head2 docroot
-
-This is the directory where your templates that you are "providing"
-live.  It is required.
-
 =head1 REQUIRED METHODS
 
 You need to implement these:
@@ -52,4 +42,10 @@ object for the request.
 
 =head1 SEE ALSO
 
+L<App::TemplateServer::Provider::Filesystem> - a role that provides some useful defaults for fs-based templating systems like TT or Mason.
+
+L<App::TemplateServer::Provider::TT> - a TT provider
+
+L<App::TemplateServer::Provider::Null> - a boring example provider
+
 L<App::TemplateServer|App::TemplateServer>
